@@ -954,7 +954,7 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "CloudShellServiceClient":
         return self
 
     def __exit__(self, type, value, traceback):
